#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-JDUsVH21zrK9Rv29N3FIZb
key:                  lsp-2.2.0.0-JDUsVH21zrK9Rv29N3FIZb
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  65f8078efb4c6015fc2e4b0cbad8955a
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-JDUsVH21zrK9Rv29N3FIZb
depends:
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy
    async-2.2.5-FIWsXw8tceP2d6lj6DHM5i
    attoparsec-0.14.4-AfQXKZj0AFm4MwPZbnzhvC base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-4F32CECC6UP7vyDdwlWkoE
    containers-0.6.7 data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    lens-5.3.4-IAs8Kog1h7NBhXd2ts4yf7
    lens-aeson-1.2.3-AQwe7GRVrjT99erLDmjqDz
    lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo mtl-2.3.1
    prettyprinter-1.7.1-6jg14vIwDos4Lqu7eMpEik
    random-1.2.1.3-3jem7NfN1E34SkjZGu3Vjy
    row-types-1.0.1.2-2FA6VL7KxweLkHrr9o9yHn
    sorted-list-0.2.3.1-6RZt8PqJUKL2QToeSYZR8m stm-2.5.1.0
    temporary-1.3-vYPArfKPXAFeZtaQhptNG text-2.0.2
    text-rope-0.3-13PtxrxbfWSEznkenTV65t transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    uuid-1.3.16-9HCSfEmPNfB3Ub0NyqmB3Q

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

